@@ -5,30 +5,36 @@ var graphInterval = '1h';
 var refInterval   = 60000;
 
 function graphChangeType(type, title) {
-    graphType = type;
     $('#gmtop').html("<span>" + title + "</span>");
-    refreshGraph();
+    graphType = type;
+    changeGraph(false);
 }
 
 function graphChangeInterval(i) {
     $("#g"+graphInterval).removeClass("gsel");
     $("#g"+i).addClass("gsel");
     graphInterval = i;
-    changeGraph();
+    changeGraph(true);
 }
 
-function changeGraph()
+function changeGraph(flash)
 {
     if (graphPrefix == 'vserver') {
 	   imgurl = '/graphs/' + graphPrefix + '_' + graphType + '_' + graphVServer + '_' + graphInterval + '.png';
     } else {
 	   imgurl = '/graphs/' + graphPrefix + '_' + graphType + '_' + graphInterval + '.png';
     }
-    $('#graphimg').attr('src', imgurl);
+
+    if (flash) {
+	   $('#graphimg').fadeOut("slow", function() {
+		  $('#graphimg').attr('src', imgurl).fadeIn("slow");
+	   });
+    } else {
+	   $('#graphimg').attr('src', imgurl);
+    }
 }
 
 function refreshGraph()
 {
-    changeGraph();
-    setTimeout(refreshGraph, refInterval);
+    setInterval(function(){ changeGraph(false); }, refInterval);
 }
