@@ -131,9 +131,9 @@ process_request_line (cherokee_handler_admin_t *ahdl, cherokee_buffer_t *line)
 ret_t 
 cherokee_handler_admin_init (cherokee_handler_admin_t *ahdl)
 {
+	ret_t                    ret;
 	char                    *tmp;
 	off_t                   postl;
-	ret_t                    ret  = ret_ok;
 	cherokee_buffer_t        post = CHEROKEE_BUF_INIT;
 	cherokee_buffer_t        line = CHEROKEE_BUF_INIT;
 	cherokee_connection_t   *conn = HANDLER_CONN(ahdl);
@@ -148,7 +148,11 @@ cherokee_handler_admin_init (cherokee_handler_admin_t *ahdl)
 
 	/* Process line per line
 	 */
-	cherokee_post_walk_read (&conn->post, &post, (cuint_t) postl);
+	ret = cherokee_post_walk_read (&conn->post, &post, (cuint_t) postl);
+	if (unlikely (ret == ret_error)) {
+		conn->error_code = http_bad_request;
+		return ret_error;
+	}
 
 	for (tmp = post.buf;;) {
 		char *end1 = strchr (tmp, CHR_LF);
