@@ -121,45 +121,3 @@ cherokee_shm_map (cherokee_shm_t    *shm,
 
 	return ret_ok;
 }
-
-
-ret_t
-cherokee_sem_init (cherokee_sem_t    *sem,
-		   cherokee_buffer_t *name)
-{
-	cherokee_buffer_init       (&sem->name);
-	cherokee_buffer_add_buffer (&sem->name, name);
-
-	sem->sem = sem_open (name->buf, 0, 0600);
-	if (sem->sem == NULL) {
-		return ret_error;
-	}
-
-	return ret_ok;
-}
-
-
-ret_t
-cherokee_sem_mrproper (cherokee_sem_t *sem)
-{
-	if (sem->sem != NULL) {
-		sem_close (sem->sem);
-		sem->sem = NULL;
-	}
-		
-	cherokee_buffer_mrproper (&sem->name);
-	return ret_ok;
-}
-
-
-ret_t
-cherokee_sem_post (cherokee_sem_t *sem)
-{
-	int re;
-
-	if (unlikely (sem->sem == NULL))
-		return ret_error;
-
-	re = sem_post (sem->sem);
-	return (re == 0) ? ret_ok : ret_error;
-}
