@@ -119,7 +119,7 @@ cherokee_validator_ldap_configure (cherokee_config_node_t *conf, cherokee_server
 			/* Not handled here
 			 */
 		} else {
-			PRINT_MSG ("Validator LDAP: Unknown key: '%s'\n", subconf->key.buf);
+			LOG_CRITICAL (CHEROKEE_ERROR_VALIDATOR_LDAP_KEY, subconf->key.buf);
 			return ret_error;
 		}
 	}
@@ -127,22 +127,22 @@ cherokee_validator_ldap_configure (cherokee_config_node_t *conf, cherokee_server
 	/* Checks
 	 */
 	if (cherokee_buffer_is_empty (&props->basedn)) {
-		LOG_ERROR_S ("LDAP validator: An entry 'base_dn' is needed\n");
+		LOG_ERROR (CHEROKEE_ERROR_VALIDATOR_LDAP_PROPERTY, "base_dn");
 		return ret_error;
 	}
 	if (cherokee_buffer_is_empty (&props->filter)) {
-		LOG_ERROR_S ("LDAP validator: An entry 'filter' is needed\n");
+		LOG_ERROR (CHEROKEE_ERROR_VALIDATOR_LDAP_PROPERTY, "filter");
 		return ret_error;
 	}
 	if (cherokee_buffer_is_empty (&props->server)) {
-		LOG_ERROR_S ("LDAP validator: An entry 'server' is needed\n");
+		LOG_ERROR (CHEROKEE_ERROR_VALIDATOR_LDAP_PROPERTY, "server");
 		return ret_error;
 	}
 
 	if ((cherokee_buffer_is_empty (&props->bindpw) &&
-	     (! cherokee_buffer_is_empty (&props->basedn)))) {
-		LOG_ERROR_S ("LDAP validator: Potential security problem found:\n"
-			     "\tanonymous bind validation. Check (RFC 2251, section 4.2.2)\n");
+	     (! cherokee_buffer_is_empty (&props->basedn))))
+	{
+		LOG_ERROR_S (CHEROKEE_ERROR_VALIDATOR_LDAP_SECURITY);
 		return ret_error;
 	}
 
@@ -161,7 +161,7 @@ init_ldap_connection (cherokee_validator_ldap_t *ldap, cherokee_validator_ldap_p
 	ldap->conn = ldap_init (props->server.buf, props->port);
 	if (ldap->conn == NULL) {
 		LOG_ERRNO (errno, cherokee_err_critical,
-			   "Couldn't connect to LDAP: %s:%d: '${errno}'", 
+			   CHEROKEE_ERROR_VALIDATOR_LDAP_CONNECT, 
 			   props->server.buf, props->port);
 		return ret_error;
 	}
@@ -173,8 +173,7 @@ init_ldap_connection (cherokee_validator_ldap_t *ldap, cherokee_validator_ldap_p
 	val = LDAP_VERSION3;
 	re = ldap_set_option (ldap->conn, LDAP_OPT_PROTOCOL_VERSION, &val);
 	if (re != LDAP_OPT_SUCCESS) {
-		LOG_ERROR ("LDAP validator: Couldn't set the LDAP version 3: %s\n", 
-			   ldap_err2string (re));
+		LOG_ERROR (CHEROKEE_ERROR_VALIDATOR_LDAP_V3, ldap_err2string(re));
 		return ret_error;		
 	}
 
@@ -187,13 +186,13 @@ init_ldap_connection (cherokee_validator_ldap_t *ldap, cherokee_validator_ldap_p
 		if (! cherokee_buffer_is_empty (&props->ca_file)) {
 			re = ldap_set_option (NULL, LDAP_OPT_X_TLS_CACERTFILE, props->ca_file.buf);
 			if (re != LDAP_OPT_SUCCESS) {
-				LOG_CRITICAL ("LDAP validator: Couldn't set CA file %s: %s\n", 
+				LOG_CRITICAL (CHEROKEE_ERROR_VALIDATOR_LDAP_CA,
 					      props->ca_file.buf, ldap_err2string (re));
 				return ret_error; 
 			}
 		}
 #else
-		LOG_ERROR_S ("Can't StartTLS, it isn't supported by LDAP client libraries\n");
+		LOG_ERROR_S (CHEROKEE_ERROR_VALIDATOR_LDAP_STARTTLS);
 #endif
 	}
 
@@ -209,9 +208,9 @@ init_ldap_connection (cherokee_validator_ldap_t *ldap, cherokee_validator_ldap_p
 	}
 
 	if (re != LDAP_SUCCESS) {
-		LOG_CRITICAL ("Couldn't bind (%s:%d): %s:%s : %s\n", 
-			      props->server.buf, props->port, props->binddn.buf, 
-			      props->bindpw.buf, ldap_err2string (re));
+		LOG_CRITICAL (CHEROKEE_ERROR_VALIDATOR_LDAP_BIND,
+			      props->server.buf, props->port, props->binddn.buf,
+			      props->bindpw.buf, ldap_err2string(re));
 		return ret_error;		
 	}
 
@@ -281,7 +280,7 @@ validate_dn (cherokee_validator_ldap_props_t *props, char *dn, char *password)
 			goto error;
 		}
 #else
-		LOG_ERROR_S ("Can't StartTLS, it isn't supported by LDAP client libraries\n");
+		LOG_ERROR_S (CHEROKEE_ERROR_VALIDATOR_LDAP_STARTTLS);
 #endif
 	}
 
@@ -342,7 +341,7 @@ cherokee_validator_ldap_check (cherokee_validator_ldap_t *ldap, cherokee_connect
 	 */
 	re = ldap_search_s (ldap->conn, props->basedn.buf, LDAP_SCOPE_SUBTREE, ldap->filter.buf, attrs, 0, &message);
 	if (re != LDAP_SUCCESS) {
-		LOG_ERROR ("Couldn't search in LDAP server: %s\n", props->filter.buf);
+		LOG_ERROR (CHEROKEE_ERROR_VALIDATOR_LDAP_SEARCH, props->filter.buf);
 		return ret_error;
 	}
 
