@@ -1,15 +1,13 @@
-import sys, string
-
-def is_letter(x):
-   if ord(x) in range(71, 91) or ord(x) in range(103, 123):
-      return True
-   return False
-
+import os, sys, string
 
 def print_block(info, len):
     print 'ret = cherokee_buffer_add (buffer, \\\n' + info + ', ' + str(len) + ');'
     print 'if (ret < ret_ok) return ret;\n'
 
+
+print 'ret = cherokee_buffer_ensure_size (buffer, %d);' % (os.path.getsize(sys.argv[1]))
+print 'if (ret < ret_ok) return ret;\n'
+
 file = open (sys.argv[1], "r")
 cont = file.read()
 file.close()
