@@ -17,7 +17,7 @@ vserver!1!rule!1130!handler!allow_pathinfo = 1
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self, __file__)
-        self.name = "dirlist w/ HeaderFile"
+        self.name = "Dirlist with header file"
 
         self.request           = "GET /header_file1/file/ HTTP/1.0\r\n"
         self.expected_error    = 200        
