@@ -58,7 +58,7 @@ class Test (TestBase):
 
 
     def Prepare (self, www):
-        from md5 import md5
+        from hashlib import md5
 
         # Create the infrastructure
         #
