@@ -330,7 +330,7 @@ class TestBase:
             return ret
 
         def CalculateResponse (self, user, realm, passwd, method, url, nonce, qop, cnonce, nc):
-            from md5 import md5
+            from hashlib import md5
 
             md5obj = md5()
             md5obj.update("%s:%s:%s" % (user, realm, passwd))
