@@ -8,16 +8,11 @@
 ##
 
 import time
-from sys import stdin
 import xml.dom.minidom
 
-DEVELOPERS = {
-    'alo'          : "Alvaro Lopez Ortega  <alvaro@octality.com>",
-    'aperez'       : "Antonio Perez  <aperez@skarcha.com>",
-    'ion'          : "Jonathan Hernandez  <ion@suavizado.com>",
-    'taher'        : "Taher Shihadeh  <taher@unixwars.com>",
-    'robertounbit' : "Roberto De Ioris <roberto@unbit.it>"
-}
+from sys import stdin
+from developers import DEVELOPERS
+
 
 def get_text (nodelist):
     for node in nodelist:
